magneticalc.QtWidgets2

# ``magneticalc`.`QtWidgets2``

package documentation

MagnetiCalc package initialization.

Module | `QButtons` | QButtons module.
Module | `QDialog2` | QDialog2 module.
Module | `QDoubleSpinBox2` | QDoubleSpinBox2 module.
Module | `QGroupBox2` | QGroupBox2 module.
Module | `QHBoxLayout2` | QHBoxLayout2 module.
Module | `QHLine` | QHLine module.
Module | `QIconLabel` | QIconLabel module.
Module | `QLabel2` | QLabel2 module.
Module | `QLayouted` | QLayouted module.
Module | `QPushButton2` | QPushButton2 module.
Module | `QSaveAction` | QSaveAction module.
Module | `QSliderFloat` | QSliderFloat module.
Module | `QSpinBox2` | QSpinBox2 module.
Module | `QTextBrowser2` | QTextBrowser2 module.